@@ -15,6 +15,7 @@ import asyncstdlib
 import discord
 from discord import VoiceProtocol
 from discord.abc import Messageable
+from discord.utils import utcnow
 
 from pylav._logging import getLogger
 from pylav.constants import REGION_TO_COUNTRY_COORDINATE_MAPPING
@@ -91,6 +92,57 @@ def _done_callback(task: asyncio.Task) -> None:
 
 
 class Player(VoiceProtocol):
+    __slots__ = (
+        "ready",
+        "bot",
+        "client",
+        "guild_id",
+        "_channel",
+        "channel_id",
+        "node",
+        "player_manager",
+        "_original_node",
+        "_voice_state",
+        "_region",
+        "_coordinates",
+        "_connected",
+        "connected_at",
+        "paused",
+        "_config",
+        "stopped",
+        "_last_update",
+        "_last_position",
+        "position_timestamp",
+        "_ping",
+        "queue",
+        "history",
+        "current",
+        "_post_init_completed",
+        "_autoplay_playlist",
+        "_restored",
+        "_effect_enabled",
+        "_volume",
+        "_equalizer",
+        "_karaoke",
+        "_timescale",
+        "_tremolo",
+        "_vibrato",
+        "_rotation",
+        "_distortion",
+        "_lowpass",
+        "_echo",
+        "_channelmix",
+        "_extras",
+        "_last_alone_paused_check",
+        "_was_alone_paused",
+        "_last_alone_dc_check",
+        "_last_empty_queue_check",
+        "_waiting_for_node",
+        "last_track",
+        "next_track",
+        "_global_config",
+        "_lavalink",
+    )
     _config: PlayerModel
     _global_config: PlayerModel
     _lavalink: Client
@@ -116,9 +168,6 @@ class Player(VoiceProtocol):
         self._coordinates = REGION_TO_COUNTRY_COORDINATE_MAPPING.get(self._region, (0, 0))
         self._connected = False
         self.connected_at = datetime.datetime.now(tz=datetime.timezone.utc)
-        self._text_channel = None
-        self._notify_channel = None
-        self._forced_vc = None
         self.last_track = None
         self.next_track = None
 
@@ -129,6 +178,7 @@ class Player(VoiceProtocol):
         self._last_update = 0
         self._last_position = 0
         self.position_timestamp = 0
+        self._ping = 0
         self.queue: PlayerQueue[Track] = PlayerQueue()
         self.history: TrackHistoryQueue[Track] = TrackHistoryQueue(maxsize=100)
         self.current: Track | None = None
@@ -188,7 +238,7 @@ class Player(VoiceProtocol):
         self._extras = await config.fetch_extras()
         self._post_init_completed = True
 
-        player_state = await self.player_manager.client.player_state_db_manager.get_player(self.channel.guild.id)
+        player_state = await self.player_manager.client.player_state_db_manager.fetch_player(self.channel.guild.id)
         if player_state:
             await self.restore(player=player_state, requester=requester or self.guild.me)
             await self.player_manager.client.player_state_db_manager.delete_player(self.channel.guild.id)
@@ -320,6 +370,10 @@ class Player(VoiceProtocol):
     def coordinates(self) -> tuple[int, int]:
         return self._coordinates
 
+    @property
+    def ping(self) -> int:
+        return self.ping
+
     @property
     def region(self) -> str | None:
         return self._region
@@ -993,7 +1047,9 @@ class Player(VoiceProtocol):
         self.current = None
         if not track:
             if self.queue.empty():
-                if await self.autoplay_enabled() and (available_tracks := (await self.get_auto_playlist()).tracks):
+                if await self.autoplay_enabled() and (
+                    available_tracks := await (await self.get_auto_playlist()).fetch_tracks()
+                ):
                     if tracks_not_in_history := list(set(available_tracks) - set(self.history.raw_b64s)):
                         track = Track(
                             node=self.node,
@@ -1251,6 +1307,7 @@ class Player(VoiceProtocol):
         self._last_update = time.time() * 1000
         self._last_position = state.get("position", 0)
         self.position_timestamp = state.get("time", 0)
+        self._ping = state.get("ping", 0)
         if self.current:
             self.current.last_known_position = self._last_position
 
@@ -1336,6 +1393,7 @@ class Player(VoiceProtocol):
             self_deaf=deaf if (deaf := await self.self_deaf()) is True else self_deaf,
         )
         self._connected = True
+        self.connected_at = utcnow()
         LOGGER.info("[Player-%s] Connected to voice channel", self.channel.guild.id)
 
     async def disconnect(self, *, force: bool = False, requester: discord.Member | None) -> None:
