@@ -166,74 +166,6 @@ def get_jar_ram_actual(executable: str) -> tuple[str, str, int, int]:
     return min_ram, max_ram, min_ram_int, max_ram_int
 
 
-def alru_cache(fn=None, maxsize=128, typed=False, *, cache_exceptions=True, ignore_kwargs=None):
-    def wrapper(fn):
-        _origin = unpartial(fn)
-
-        if not asyncio.iscoroutinefunction(_origin):
-            raise RuntimeError(f"Coroutine function is required, got {fn}")
-
-        # functools.partialmethod support
-        if hasattr(fn, "_make_unbound_method"):
-            fn = fn._make_unbound_method()
-
-        @functools.wraps(fn)
-        async def wrapped(*fn_args, **fn_kwargs):
-            if wrapped.closed:
-                raise RuntimeError(f"alru_cache is closed for {wrapped}")
-
-            loop = asyncio.get_event_loop()
-
-            key = _make_key(fn_args, fn_kwargs, typed)
-
-            fut = wrapped._cache.get(key)
-
-            if fut is not None:
-                if not fut.done():
-                    _cache_hit(wrapped, key)
-                    return await asyncio.shield(fut)
-
-                exc = fut._exception
-
-                if exc is None or cache_exceptions:
-                    _cache_hit(wrapped, key)
-                    return fut.result()
-
-                # exception here and cache_exceptions == False
-                wrapped._cache.pop(key)
-
-            fut = loop.create_future()
-            task = loop.create_task(fn(*fn_args, **fn_kwargs))
-            task.add_done_callback(functools.partial(_done_callback, fut))
-            wrapped.tasks.add(task)
-            task.add_done_callback(wrapped.tasks.remove)
-            wrapped._cache[key] = fut
-            if maxsize is not None and len(wrapped._cache) > maxsize:
-                wrapped._cache.popitem()
-
-            _cache_miss(wrapped, key)
-            return await asyncio.shield(fut)
-
-        _cache_clear(wrapped)
-        wrapped._origin = _origin
-        wrapped.closed = False
-        wrapped.cache_info = functools.partial(_cache_info, wrapped, maxsize)
-        wrapped.cache_clear = functools.partial(_cache_clear, wrapped)
-        wrapped.invalidate = functools.partial(_cache_invalidate, wrapped, typed)
-        wrapped.close = functools.partial(_close, wrapped)
-        wrapped.open = functools.partial(_open, wrapped)
-
-        return wrapped
-
-    if fn is None:
-        return wrapper
-
-    if callable(fn) or hasattr(fn, "_make_unbound_method"):
-        return wrapper(fn)
-
-    raise NotImplementedError(f"{fn} decorating is not supported")
-
-
 def shorten_string(string: str, max_length: int, right: bool = True) -> str:
     if len(string) > max_length:
         if right:
@@ -326,7 +258,7 @@ class MissingSentinel(str):
 MISSING: Any = MissingSentinel("MISSING")
 
 
-@dataclasses.dataclass(eq=True)
+@dataclasses.dataclass(eq=True, slots=True, unsafe_hash=True, order=True, kw_only=True, frozen=True)
 class TimedFeature:
     enabled: bool = False
     time: int = 60
@@ -394,6 +326,8 @@ class PlayerQueue(asyncio.Queue[T]):
     interrupted between calling qsize() and doing an operation on the Queue.
     """
 
+    __slots__ = ("_queue", "_maxsize", "_getters", "_putters", "_unfinished_tasks", "_finished", "_loop")
+
     _queue: collections.deque[T]
     raw_b64s: list[str]
 
@@ -665,6 +599,8 @@ class PlayerQueue(asyncio.Queue[T]):
 
 
 class TrackHistoryQueue(PlayerQueue[T]):
+    __slots__ = ("_queue", "_maxsize", "_getters", "_putters", "_unfinished_tasks", "_finished", "_loop")
+
     def __int__(self, maxsize: int = 0) -> None:
         super().__init__(maxsize=maxsize)
 
@@ -1130,6 +1066,8 @@ class AsyncFilter(AsyncIterator[_T], Awaitable[list[_T]]):  # pylint: disable=du
     We don't recommend instantiating this class directly.
     """
 
+    __slots__ = ("__func", "__iterable", "__generator_instance")
+
     def __init__(
         self,
         func: Callable[[_T], bool | Awaitable[bool]],
@@ -1348,6 +1286,8 @@ class AsyncIter(AsyncIterator[_T], Awaitable[list[_T]]):  # pylint: disable=dupl
 
     """
 
+    __slots__ = ("_delay", "_iterator", "_i", "_steps", "_map")
+
     def __init__(self, iterable: Iterable[_T], delay: float | int = 0, steps: int = 100) -> None:
         if steps < 1:
             raise ValueError("Steps must be higher than or equals to 1")
@@ -1624,6 +1564,8 @@ class MessagePredicate(Callable[[discord.Message], bool]):
 
     """
 
+    __slots__ = ("result", "_pred")
+
     def __init__(self, predicate: Callable[[MessagePredicate, discord.Message], bool]) -> None:
         self._pred: Callable[[MessagePredicate, discord.Message], bool] = predicate
         self.result = None
